@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocosi::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocosi::VERSION = '0.01';
+  $App::Pocosi::VERSION = '0.02';
 }
 
 use strict;
@@ -452,7 +452,7 @@ sub ircd_plugin_status {
 sub ircd_shutdown {
     my ($self) = $_[OBJECT];
     $self->_event_debug([@_[ARG0..$#_]], 'IRCD_shutdown') if $self->{trace};
-    $self->_status('normal', 'IRC component shut down');
+    $self->_status('normal', 'IRCd component shut down');
     return;
 }
 
@@ -575,7 +575,7 @@ L<POE::Component::Server::IRC|POE::Component::Server::IRC> instance.
 =item * Offers a user friendly way to pass arguments to POE::Component::Server::IRC
 
 =item * Has an interactive mode where you can issue issue commands and
-call methods on the IRC component(s).
+call methods on the IRCd component.
 
 =back
 
@@ -720,7 +720,7 @@ Here is some example output from the program:
  ^C2011-05-22 15:30:18 Exiting due to SIGINT
  2011-05-22 15:30:18 Deleted plugin OperServ_1
  2011-05-22 15:30:18 Deleted plugin PocosiStatus_1
- 2011-05-22 15:30:18 IRC component shut down
+ 2011-05-22 15:30:18 IRCd component shut down
 
 =head1 AUTHOR
 
